//Interrupts for Battery management/saving using MCU power down mode. /INTA from RX8025 is connected to INT0 of MCU.

#include <avr/sleep.h>
#include <Wire.h>
#include "R8025.h"

R8025 RTC; //Create the R8025 object
static uint8_t prevSecond=0; 

void setup () 
{
     /*Initialize INT0 for accepting interrupts */
     PORTD |= 0x04; 
     DDRD &=~ 0x04;
  
     Serial.begin(57600);
     Wire.begin();
    
     RTC.begin();
     attachInterrupt(0, INT0_ISR, FALLING); 
     
     //Enable Interrupt 
     RTC.enableINTA_Interrupts(EverySecond); //interrupt at  EverySecond, EveryMinute, EveryHour or EveryMonth
     // or this
     //RTC.enableINTA_Interrupts(19,18);    // interrupt at (h,m)
}


void loop () 
{

    DateTime now = RTC.now(); //get the current date-time    
    if((now.second()) !=  prevSecond )
    {
    //print only when there is a change second
    Serial.print(now.year(), DEC);
    Serial.print('/');
    Serial.print(now.month(), DEC);
    Serial.print('/');
    Serial.print(now.date(), DEC);
    Serial.print(' ');
    Serial.print(now.hour(), DEC);
    Serial.print(':');
    Serial.print(now.minute(), DEC);
    Serial.print(':');
    Serial.print(now.second(), DEC);
    Serial.println(' ');
    }
    prevSecond = now.second();
 
    RTC.refreshINTA(); //This function call is  a must to bring /INTA pin HIGH after interrupt
    //RTC.disableINTA_Interrupts //uncomment this if required
} 

 
  
//Interrupt service routine for external interrupt on INT0 pin conntected to /INTA
void INT0_ISR()
{
  //Keep this as short as possible. Possibly avoid using function calls
  
    Serial.println(" External Interrupt detected ");
}
