//Battery management/saving using MCU power down mode. /INTA from RX8025 is connected to INT0 of MCU.

#include <avr/sleep.h>
#include <Wire.h>
#include "R8025.h"

R8025 RTC; //Create the R8025 object
static uint8_t prevMinute=0; 

void setup () 
{
     /*Initialize INT0 for accepting interrupts */
     PORTD |= 0x04; 
     DDRD &=~ 0x04;
   
     Serial.begin(57600);
     Wire.begin();
    
     RTC.begin();
     attachInterrupt(0, INT0_ISR, LOW); //Only LOW level interrupt can wake up from PWR_DOWN
     set_sleep_mode(SLEEP_MODE_PWR_DOWN);
       
     //Enable Interrupt 
     RTC.enableINTA_Interrupts(EveryMinute); //interrupt at  EverySecond, EveryMinute, EveryHour or EveryMonth
     // or this
     //RTC.enableINTA_Interrupts(19,18);    // interrupt at (h,m)
}

void loop () 
{
    //START : Application code
   
    DateTime now = RTC.now(); //get the current date-time    
    if((now.minute()) !=  prevMinute )
    {
    //print only when there is a change second
    Serial.print(now.year(), DEC);
    Serial.print('/');
    Serial.print(now.month(), DEC);
    Serial.print('/');
    Serial.print(now.date(), DEC);
    Serial.print(' ');
    Serial.print(now.hour(), DEC);
    Serial.print(':');
    Serial.print(now.minute(), DEC);
    Serial.print(':');
    Serial.print(now.second(), DEC);
    Serial.println(' ');
    }
    prevMinute = now.minute();
    
    RTC.refreshINTA(); //This function call is  a must to bring /INTA pin HIGH after interrupt
    attachInterrupt(0, INT0_ISR, LOW); 
    //RTC.disableINTA_Interrupts //uncomment this if required
    
    //END : Application code 
   
    //Shut down all peripherals like ADC before sleep. Refer Atmega328 manual
    
    //Power Down routines
    cli();
    sleep_enable();      // Set sleep enable bit
    sleep_bod_disable(); // Disable brown out dection during sleep. Saves more power
    sei();
    Serial.println("Sleeping");
    delay(10); //This delay is required to allow print to complete
    sleep_cpu();         // Sleep the CPU as per the mode set earlier(power down)  
    sleep_disable();     // Wakes up sleep and clears enable bit. Before this ISR would have executed
    delay(10); //This delay is required to allow CPU to stabilize
    Serial.println("Awake from sleep\n");    

} 

 
  
//Interrupt service routine for external interrupt on INT0 pin conntected to /INTA
void INT0_ISR()
{
  //Keep this as short as possible. Possibly avoid using function calls
    detachInterrupt(0); 
    Serial.println(" I'm ISR. ");
}
